data {
	int<lower=0> I; 		// number of solutes
	int<lower=0> J; 		// number of solvents
	int<lower=0> K; 		// number of latent dimensions
	real xi[I*J]; 			// matrix of binary interaction parameters
	real<lower=0> sigma_0; 		// prior standard deviation
	real<lower=0> sigma_0_CompBias; // prior standard deviation of component bias
	real lambda_xi; 		// likelihood standard deviation

}

parameters {
	vector[K] u[I]; // solute feature vectors
	vector[K] v[J]; // solvent feature vectors
	real u_bias[I]; // solute bias
	real v_bias[J]; // solvent bias
}

model {
        int ii;
        int jj;

	// define the prior distributions for the parameters
     	for (i in 1:I){
	    	u[i] ~ normal(0,sigma_0);
	    	u_bias[i] ~ normal(0,sigma_0_CompBias);
     	}
       	for (j in 1:J) {
		   v[j] ~ normal(0,sigma_0);
		   v_bias[j] ~ normal(0,sigma_0_CompBias);
	    }
    
	// model the likelihood
        ii = 1;
        jj = 1;
	    for (idx in 1:I*J) {
		    if (xi[idx] != -99) {
			    xi[idx] ~ normal(u[ii]' * v[jj] + u_bias[ii] + v_bias[jj], lambda_xi);
		    }
            ii = ii+1;
            if (ii > I) {
                ii = 1;
                jj = jj+1;
            }
	    }
}